@@ -28,23 +28,34 @@ import os.path
 
 # 3rd party
 import sphinx_rtd_theme  # type: ignore
+from sphinx.application import Sphinx
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT License"
-__version__: str = "0.0.10"
+__version__: str = "0.1.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __version_full__ = __version__
 
+__all__ = ["setup"]
+
+
+def setup(app: Sphinx):
+	"""
+	Setup Sphinx extension.
+
+	:param:
+	"""
 
-def setup(app):
 	# add_html_theme is new in Sphinx 1.6+
 	sphinx_rtd_theme.setup(app)
+
 	if hasattr(app, "add_html_theme"):
 		theme_path = os.path.abspath(os.path.dirname(__file__))
 		app.add_html_theme("domdf_sphinx_theme", theme_path)
+
 	return {
 			"version": __version__,
 			"parallel_read_safe": True,
